==> haskell-murmur-hash-0.1.0.9-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: murmur-hash
version: 0.1.0.9
id: murmur-hash-0.1.0.9-Kb2RNFbk42fBtX0CoM74R5
key: murmur-hash-0.1.0.9-Kb2RNFbk42fBtX0CoM74R5
license: BSD3
maintainer: Thomas Schilling <nominolo@googlemail.com>
stability: provisional
homepage: http://github.com/nominolo/murmur-hash
synopsis: MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.
    .
    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.
category: Data, Digest
author: Thomas Schilling
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Murmur32 Data.Digest.Murmur64
abi: 9c06752eea47efe8fead2e51d7943a6a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/murmur-hash-0.1.0.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/murmur-hash-0.1.0.9
hs-libraries: HSmurmur-hash-0.1.0.9-Kb2RNFbk42fBtX0CoM74R5
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html: /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-murmur-hash-0.1.0.9-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-murmur-hash.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: murmur-hash
version: 0.1.0.9
id: murmur-hash-0.1.0.9-58saU5wLuI95RQk0lfaLJm
key: murmur-hash-0.1.0.9-58saU5wLuI95RQk0lfaLJm
license: BSD3
maintainer: Thomas Schilling <nominolo@googlemail.com>
stability: provisional
homepage: http://github.com/nominolo/murmur-hash
synopsis: MurmurHash2 implementation for Haskell.
description:
    Implements MurmurHash2, a good, fast, general-purpose,
    non-cryptographic hashing function.  See
    <http://murmurhash.googlepages.com/> for details.
    .
    This implementation is pure Haskell, so it might be a bit slower
    than a C FFI binding.
category: Data, Digest
author: Thomas Schilling
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Murmur32 Data.Digest.Murmur64
abi: b754df507cbee4444792128a2d52a1e3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/murmur-hash-0.1.0.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/murmur-hash-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/murmur-hash-0.1.0.9
hs-libraries: HSmurmur-hash-0.1.0.9-58saU5wLuI95RQk0lfaLJm
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-murmur-hash/html/murmur-hash.haddock
haddock-html: /usr/share/doc/haskell-murmur-hash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
